# AxiomX 0.1.0.dev8

AxiomX is proud to release the 0.1.0.dev8 bugfix release. We're extremely sorry for the inconvenience we have caused. We had realized about a bug running in our module. We have fixed it and as this is a bugfix release, we have not added anything new.
\
\
This module is licensed under MIT. No one is allowed to copy code from AxiomX. Hope you all enjoy AxiomX.